commit 5727cb2d4346c31aad04000f8407bdee21d9e594
Author: Georg Baum <[email protected]>
Date:   Thu Jan 28 20:59:01 2016 +0100

    Use consistent iconv encoding names
    
    We should stick to the names used in lib/encodings. iconv has many aliases,
    but fi we ever compare names it is better to use only one variant.

diff --git a/src/tex2lyx/tex2lyx.cpp b/src/tex2lyx/tex2lyx.cpp
index 5001ad0..4ce2512 100644
--- a/src/tex2lyx/tex2lyx.cpp
+++ b/src/tex2lyx/tex2lyx.cpp
@@ -844,12 +844,12 @@ bool tex2lyx(idocstream & is, ostream & os, string 
encoding,
 {
        // Set a sensible default encoding.
        // This is used until an encoding command is found.
        // For child documents use the encoding of the master, else ISO8859-1,
        // (formerly known by its latex name latin1), since ISO8859-1 does not
        // cause an iconv error if the actual encoding is different (bug 7509).
        if (encoding.empty()) {
                if (preamble.inputencoding() == "auto")
-                       encoding = "ISO8859-1";
+                       encoding = "ISO-8859-1";
                else {
                        Encoding const * const enc = encodings.fromLyXName(
                                preamble.inputencoding(), true);
@@ -844,12 +844,12 @@ bool tex2lyx(idocstream & is, ostream & os, string 
        // Set a sensible default encoding.
        // This is used until an encoding command is found.
-       // For child documents use the encoding of the master, else ISO8859-1,
-       // (formerly known by its latex name latin1), since ISO8859-1 does not
+       // For child documents use the encoding of the master, else ISO-8859-1,
+       // (formerly known by its latex name latin1), since ISO-8859-1 does not
        // cause an iconv error if the actual encoding is different (bug 7509).
        if (encoding.empty()) {

Reply via email to